@@ -1,21 +1,21 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
 /* GeoIPUpdate.c
  *
- * Copyright (C) 2004 MaxMind LLC
+ * Copyright (C) 2006 MaxMind LLC
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "GeoIPCity.h"
@@ -40,6 +40,8 @@
 #include <stdio.h>
 #include <unistd.h>
 
+#define BLOCK_SIZE 1024
+
 const char *GeoIPUpdateHost = "updates.maxmind.com";
 const char *GeoIPHTTPRequest = "GET /app/update?license_key=%s&md5=%s HTTP/1.0\nHost: updates.maxmind.com\n\n";
 const char *GeoIPHTTPRequestMD5 = "GET /app/update_secure?db_md5=%s&challenge_md5=%s&user_id=%s&edition_id=%s HTTP/1.0\nHost: updates.maxmind.com\n\n";
@@ -109,7 +111,6 @@ short int GeoIP_update_database (char * license_key, int verbose, void (*f)( cha
 	char * buf;
 	struct sockaddr_in sa;
 	int offset = 0, err;
-	int block_size = 1024;
 	char * request_uri;
 	char * compr;
 	unsigned long comprLen;
@@ -123,7 +124,8 @@ short int GeoIP_update_database (char * license_key, int verbose, void (*f)( cha
 	char *f_str;
 	GeoIP * gi;
 	char * db_info;
-	char block[block_size];
+	char block[BLOCK_SIZE];
+	int block_size = BLOCK_SIZE;
 
 	_GeoIP_setup_dbfilename();
 
@@ -268,7 +270,7 @@ short int GeoIP_update_database (char * license_key, int verbose, void (*f)( cha
 		if (amt == 0) {
 			break;
 		}
-		fwrite(block,1,block_size,gi_fh);
+		fwrite(block,1,amt,gi_fh);
 	}
 	gzclose(gz_fh);
 	unlink(file_path_gz);
@@ -348,7 +350,6 @@ short int GeoIP_update_database_general (char * user_id,char * license_key,char
 	char * buf;
 	struct sockaddr_in sa;
 	int offset = 0, err;
-	int block_size = 1024;
 	char * request_uri;
 	char * compr;
 	unsigned long comprLen;
@@ -369,7 +370,8 @@ short int GeoIP_update_database_general (char * user_id,char * license_key,char
 	char *tmpstr;
 	int dbtype;
 	int lookupresult = 1;
-	char block[block_size];
+	char block[BLOCK_SIZE];
+	int block_size = BLOCK_SIZE;
 
 	hostlist = gethostbyname(GeoIPUpdateHost);
 
